<?php
/** Bakhtiari (بختياري)
 *
 * See MessagesQqq.php for message documentation incl. usage of parameters
 * To improve a translation please visit http://translatewiki.net
 *
 * @ingroup Language
 * @file
 *
 * @author Behdarvandyani
 * @author GerardM
 * @author Huji
 * @author Meno25
 */

$fallback = 'fa';

$rtl = true;

$messages = array(
# User preference toggles
'tog-underline' => 'لینکهای خط به زیر',
'tog-justify' => 'فاصله نهادن سی پاراگرافها',
'tog-hideminor' => 'من ته نبیدن تغییرات کوچیک',
'tog-extendwatchlist' => 'گپ کردن لیستهای من ته سی دیدن همه تغییراتی که ابوه',
'tog-usenewrc' => 'گپ کردن تغییرات آخری - جاوااسکریپت',
'tog-numberheadings' => 'شماره وندن خودکار سی سرخط ها',
'tog-showtoolbar' => 'نشو دادن تغییرات  تولبار  یا   جای نشودادن ابزارها- جاوااسکریپت',
'tog-editondblclick' => 'اصلاح صفحات با دوبار کلیک - جاوااسکریپت',
'tog-editsection' => 'امکان اصلاح یه قسمت زه راه لینکها',
'tog-editsectiononrightclick' => 'امکان اصلاح یه قسمت زه راه راست کلیک کردن رو عنوان  اوقسمت- جاوااسکریپت',
'tog-showtoc' => 'نشودادن فهرست محتوا سی صفحاتی که بیشتر زه سه سرخط دارن',
'tog-rememberpassword' => 'به حافظه کامپیوتر دادن نحوه ورودی خوم (for a maximum of $1 {{PLURAL:$1|day|days}})',
'tog-watchcreations' => 'اضاف کردن اوصفحاتی که خوم درست کردم به فهرست نمایشی',
'tog-watchdefault' => 'اضاف کردن اوصفحاتی که خوم اصلاح کردم به فهرست نمایشی',
'tog-watchmoves' => 'اضاف کردن صفحاتی که خوم جابجا کردم به فهرست نمایشی',
'tog-watchdeletion' => 'اضاف کردن صفحاتی که خوم پاک کردم به فهرست نمایشی خوم',
'tog-minordefault' => 'علامت نهادن به اصلاحات ناقص',
'tog-previewontop' => 'نشودادن پیش نمایش قبل از یوکه جعبه یا کادر اصلاح بوه',
'tog-previewonfirst' => 'نشو دادن پیش نمایش  دراصلاح اول',
'tog-nocache' => 'ناتوان کردن صفحه  درحال کچ',
'tog-enotifwatchlistpages' => 'امیل به مو وقتی که  صفحه ای که منه فهرست نمایش مونه تغییر کرد',
'tog-enotifusertalkpages' => 'امیل به مو وقتی که صفحه گفتگوی مو تغییر کرد',
'tog-enotifminoredits' => 'امیل به مو سی صفحات ناقص اصلاح شده',
'tog-enotifrevealaddr' => 'نشودادن امیل مو درامیلهای آگاهی-خبری',
'tog-shownumberswatching' => 'نشودادن شماره کاربران درحال کار یاتماشا',
'tog-fancysig' => 'امضاهای ناتمام - بدون لینکهای اتوماتیک',
'tog-showjumplinks' => 'قادر ساختن "پرش به" لینکهای دردسترس',
'tog-uselivepreview' => 'استفاده زه پیش نمایش زنده(جاوااسکریپ) (تجربی )',
'tog-forceeditsummary' => 'یادآوری سریع به مو هنگام اصلاح عقیم وخلاصه',
'tog-watchlisthideown' => 'قایم کردن اصلاحات مو  زه لیست پیگیریها',
'tog-watchlisthidebots' => 'قایم کردن اصلاحات بوت زه لیست پیگیریها',
'tog-watchlisthideminor' => 'قایم کردن اصلاحات ریز زه لیست پیگیریها',
'tog-watchlisthideliu' => 'قایم کردن اصلاحات انجام وابیده  بوسیله کاربران داخل سیستم وابیده زه لیست پیگیریها',
'tog-watchlisthideanons' => 'قایم کردن اصلاحات انجام شده بوسیله کاربران داخل سیستم نشده زه لیست پیگیری',
'tog-ccmeonemails' => 'ارسال کپی امیلهایی که مو به  کاربران دیه ارسال کردم به مو',
'tog-diffonly' => 'نشو نده صفحه ای که دارای محتوای متفاوت زیره',
'tog-showhiddencats' => 'نشودادن دسته بندیهای قایم شده',

'underline-always' => 'همیشه',
'underline-never' => 'هرگز',
'underline-default' => 'پیش نمایش مرورگر',

# Dates
'sunday' => 'یکشنبه',
'monday' => 'دوشنبه',
'tuesday' => 'سه‌شنبه',
'wednesday' => 'چهارشنبه',
'thursday' => 'پنجشنبه',
'friday' => 'جمعه',
'saturday' => 'شنبه',
'sun' => 'یکشنبه',
'mon' => 'دوشنبه',
'tue' => 'سه‌شنبه',
'wed' => 'چهارشنبه',
'thu' => 'پنجشنبه',
'fri' => 'جمعه',
'sat' => 'شنبه',
'january' => 'ژانویه',
'february' => 'فوریه',
'march' => 'مارس',
'april' => 'آوریل',
'may_long' => 'مه',
'june' => 'ژوئن',
'july' => 'ژوئیه',
'august' => 'اوت',
'september' => 'سپتامبر',
'october' => 'اکتبر',
'november' => 'نوامبر',
'december' => 'دسامبر',
'january-gen' => 'ژانویه',
'february-gen' => 'فوریه',
'march-gen' => 'مارس',
'april-gen' => 'آوریل',
'may-gen' => 'مه',
'june-gen' => 'ژوئن',
'july-gen' => 'ژوئیه',
'august-gen' => 'اوت',
'september-gen' => 'سپتامبر',
'october-gen' => 'اکتبر',
'november-gen' => 'نوامبر',
'december-gen' => 'دسامبر',
'jan' => 'ژانویه',
'feb' => 'فوریه',
'mar' => 'مارس',
'apr' => 'آوریل',
'may' => 'مه',
'jun' => 'ژوئن',
'jul' => 'ژوئیه',
'aug' => 'اوت',
'sep' => 'سپتامبر',
'oct' => 'اکتبر',
'nov' => 'نوامبر',
'dec' => 'دسامبر',

# Categories related messages
'pagecategories' => '{{PLURAL:$1|دسته|دسته ها}}',
'category_header' => 'صفحات دردسته "$1"',
'subcategories' => 'دسته های فرعی',
'category-media-header' => 'مدیا دردسته "$1"',
'category-empty' => 'ای دسته درحال حاضر دارای هیچ صفحه یا مدیایی نه',
'hidden-categories' => '{{PLURAL:$1|دسته قایم|دسته های قایم}}',
'hidden-category-category' => 'دسته های قایم',
'category-subcat-count' => '{{PLURAL:$2|ای دسته فقط دسته های فرعی زیر راداره.|ای دسته چیزهای زیر راداره {{PLURAL:$1|دسته فرعی|$1 دسته های فرعی}}, بیشتراز$2 کل.}}',
'category-subcat-count-limited' => 'ای دسته چیزهای زیر راداره {{PLURAL:$1|دسته فرعی|$1 دسته های فرعی}}.',
'category-article-count' => '{{PLURAL:$2|ای دسته فقط دارای صفحات زیره.|ذیل الذکر{{PLURAL:$1|صفحه است|$1 صفحات هستند}} دراین دسته, بیشترزه$2 کل.}}',
'category-article-count-limited' => 'ذیل الذکر {{PLURAL:$1|صفحه است|$1 صفحات هستند}} درآن دسته جریانی.',
'category-file-count' => '{{PLURAL:$2|ای دسته فقط فایلهای زیر راداره.|ذیل الذکر{{PLURAL:$1|فایل است|$1 فایلهاهستند}} درای دسته, بیشترزه$2 کل.}}',
'category-file-count-limited' => 'ذیل الذکر {{PLURAL:$1|فایل است|$1 فایلها هستند}} درآن دسته جریانی.',
'listingcontinuesabbrev' => 'دنباله',

'about' => 'درباره',
'newwindow' => '(پنجره تازه واز کن)',
'cancel' => 'لغو',
'mytalk' => 'صحبت مو',

# Cologne Blue skin
'qbfind' => 'پیدا کردن',
'qbedit' => 'اصلاح',
'faq' => 'اف ای کیو',
'faqpage' => 'Project:اف ای کیو',

'errorpagetitle' => 'خطا',
'returnto' => 'بازگشت به $1.',
'tagline' => 'از {{SITENAME}}',
'help' => 'راهنما',
'search' => 'جستن',
'searchbutton' => 'جستن',
'searcharticle' => 'برو',
'history' => 'گزارش صفحه',
'history_short' => 'گزارش تاریخی',
'printableversion' => 'نسخه قابل چاپ',
'permalink' => 'لینک دایمی',
'edit' => 'اصلاح',
'editthispage' => 'اصلاح ای صفحه',
'delete' => 'حذف',
'protect' => 'حفاظت وحمایت',
'newpage' => 'صفحه تازه',
'talkpage' => 'بحث ای صفحه',
'talkpagelinktext' => 'صحبت',
'specialpage' => 'صفحه مخصوص',
'personaltools' => 'ابزارهای شخصی',
'postcomment' => 'ارسال یک توضیح',
'articlepage' => 'دیدن صفحه محتوا',
'talk' => 'بحث',
'views' => 'مشاهدات',
'toolbox' => '
جعبه ابزار',
'userpage' => 'دیدن صفحه کاربر',
'projectpage' => 'دیدن صفحه پروژه',
'imagepage' => 'دیدن صفحه مدیا',
'mediawikipage' => 'دیدن صفحه پیام',
'templatepage' => 'دیدن صفحه قالب',
'viewhelppage' => 'دیدن صفحه کمک',
'categorypage' => 'دیدن صفحه طبقه بندی',
'viewtalkpage' => 'دیدن بحث ها',
'otherlanguages' => 'درزبانهای دیگر',
'redirectedfrom' => '(تصحیح مجدداز$1)',
'redirectpagesub' => 'صفحه تصحیح وهدایت مجدد',
'lastmodifiedat' => 'این صفحه اخیرا تغییر واصلاح شددر $1, در $2.',
'viewcount' => 'این صفحه قابل دسترسی شده است {{PLURAL:$1|once|$1 times}}.',
'protectedpage' => 'صفحه حمایت شده',
'jumpto' => 'پریدن به:',
'jumptonavigation' => 'راندن یا هدایت کردن',
'jumptosearch' => 'جستن',

# All link text and link target definitions of links into project namespace that get used by other message strings, with the exception of user group pages (see grouppage) and the disambiguation template definition (see disambiguations).
'aboutsite' => 'درباره {{SITENAME}}',
'aboutpage' => 'Project:درباره',
'copyright' => 'محتوا باای شماره قابل دسترسیه
 $1.',
'copyrightpage' => '{{ns:project}}:کپی رایت',
'currentevents' => 'اتفاقات جاری',
'currentevents-url' => 'Project:اتفاقات جاری',
'disclaimers' => 'انکار کننده ها',
'disclaimerpage' => 'Project:انکار کاربران',
'edithelp' => 'کمک برای اصلاح',
'edithelppage' => 'Help:اصلاح',
'helppage' => 'Help:محتوا',
'mainpage' => 'صفحه اصلی',
'mainpage-description' => 'صفحه اصلی',
'policy-url' => 'Project:خط مشی',
'portal' => 'درگاه کاربران',
'portal-url' => 'Project:درگاه کاربران',
'privacy' => 'خط مشی رازداری',
'privacypage' => 'Project:خط مشی رازداری',

'badaccess' => 'خطا :اجازه بگیر',
'badaccess-group0' => 'ایسا اجازه انجام کاری که خواستین را ندارین',
'badaccess-groups' => 'او کاری که ایسا درخواست کردین فقط سی کاربرانیه که من ای  گروهن
{{PLURAL:$2|آن گروه|یکی زه گروهها}}: $1.',

'versionrequired' => 'یه نسخه زه نیازمندیهای ویکی مدیا
$1',
'versionrequiredtext' => 'یه نسخه زه ویکی مدیا($1) نیازمند ه به استفاده زه ای صفحه
بوین :[[Special:Version|version page]].',

'ok' => 'خووه',
'pagetitle-view-mainpage' => 'سرصفحه',
'retrievedfrom' => 'بازیافت از"$1"',
'youhavenewmessages' => 'پیام تاره داری $1 ($2).',
'newmessageslink' => 'پیام تازه',
'newmessagesdifflink' => 'تغییر آخری',
'youhavenewmessagesmulti' => 'ایسا پیام تازه دارین منه
$1',
'editsection' => 'اصلاح',
'editold' => 'اصلاح',
'viewsourceold' => 'دیدن منبع',
'editsectionhint' => 'اصلاح یه قسمت: $1',
'toc' => 'محتواها',
'showtoc' => 'نمایش',
'hidetoc' => 'قایم',
'thisisdeleted' => 'دیدن یا اعاده $1?',
'viewdeleted' => 'دیدن$1?',
'restorelink' => '{{PLURAL:$1|پاک کردن یه اصلاح|$1 پاک کردن اصلاحات}}',
'feedlinks' => 'تغذیه:',
'feed-invalid' => 'اشتراک  زه راه  تایپ باطله',
'site-rss-feed' => 'خبرخو RSS سی $1',
'site-atom-feed' => 'خبرخو Atom سی $1',
'page-rss-feed' => 'خبرخو RSS سی «$1»',

# Short words for each namespace, by default used in the namespace tab in monobook
'nstab-user' => 'صفحه کاربر',
'nstab-project' => 'صفحه پروژه',
'nstab-image' => 'فایل',
'nstab-template' => 'قالب یا الگو',
'nstab-category' => 'دسته',

# General errors
'badtitle' => 'عنوان بد',
'badtitletext' => 'عنوان درخواستی نامعتبر، خالی، یا عنوانی بین زبانی یا بین‌ویکی‌ای با پیوند نادرسته
و ممکنه دارای یک یا چند کاراکتر بوه که در عنوان مربوط نوا زش استفاده کنین',
'viewsource' => 'مشاهده منبع',
'viewsourcetext' => 'ایسا ترین بوینین وکپی کنین منبع ای صفحه را:',

# Login and logout pages
'yourname' => 'نام کاربر:',
'yourpassword' => 'رمز:',
'remembermypassword' => 'رمز اویدن به سیستم را دراین رایانه به خاطر بسپار (for a maximum of $1 {{PLURAL:$1|day|days}})',
'login' => 'اویدن به سیستم',
'nav-login-createaccount' => 'اویدن به سیستم',
'loginprompt' => 'ایسا وا کوکی ها رافعال کنین سی اویدن به  {{SITENAME}}.',
'userlogin' => 'اویدن به سیستم / درست کردن حساب کاربری',
'logout' => 'رهدن زه سیستم',
'userlogout' => 'رهدن زه سیستم',
'nologin' => "آیا ایسا حساب کاربری ندارین? '''$1'''.",
'nologinlink' => 'درست کردن یه حساب کاربری',
'createaccount' => 'درست کردن حساب کاربری',
'gotaccount' => "آیا تقریبا یه حساب کاربری دارین? '''$1'''.",
'gotaccountlink' => 'اویدن به',
'loginsuccesstitle' => 'اویدن با بخت وتوفیق به سیستم',
'loginsuccess' => "''' ایسا اویدن به داخل سایت {{SITENAME}} بعنوان \"\$1\".'''",
'nosuchuser' => 'کاربری به ای نام وجود نداره "$1".
حروف نام را چک کنین, یا [[Special:UserLogin/signup|درست کنین یه حساب کاربری تازه]].',
'nosuchusershort' => 'کاربری به ای نام وجود نداره"$1".
حروف نام راچک کنین.',
'nouserspecified' => 'ایسا دارین یه نام کاربر ذکر اکنین.',
'wrongpassword' => 'رمز وارد وابیده درست نه.
لطفا دوباره سعی کنین.',
'wrongpasswordempty' => 'رمز وارد وابیده عقیم یامبهم بی.
لطفا دوباره سعی کنین.',
'passwordtooshort' => 'رمز ایسا غیر معتبر یا کوتاه هده.
آن وا داشته بوه حداقل {{PLURAL:$1|1 کاراکتر|$1 کاراکترها}} همچنین وا زه نام کاربریتو متفاوت بوه.',
'mailmypassword' => 'امیل رمز تازه',
'passwordremindertitle' => 'رمز موقتی تازه سی {{SITENAME}}',
'passwordremindertext' => 'یه نفر (شاید خودتو, زه نشانی آی پی$1) درخواست یه رمز تازه کرده سی {{SITENAME}} ($4). یه رمز موقتی سی کاربر
"$2" درست شده وگذاشته وابیده به"$3". ایر مطابق میل ایسا بوه, نیازه که داخل سیستم بوین ویه رمز تازه انتخاب کنین.

ایر آن فرد همچنین درخواست کرده بوه  یونه, یا ایر ایسا رمزتو را به خاط داشته این ,
وسی مدت طولانی نه خوین هونه تغییر بدین, ایسا وا نادیده بگیرین ای پیام  را وهمچنان زه رمز قدیمی خوتو استفاده کنین',
'noemail' => 'وجود نداره نشانی امیل ضبط وابده زه کاریر "$1".',
'passwordsent' => 'یه رمز تازه ارسال وابید به نشانی امیل ثبت وابده سی "$1".
لطفا بعد از دریافت آن داخل سیستم بوین.',
'eauthentsent' => 'یه نامه الکترونیکی سی تایید نشانی پست الکترونیکی به نشانی مورنظر ارسال وابید. قبل زه یو که نامه دیگری قابل ارسال به این نشانی بوه، وا دستورهایی که در آن نامه اویده را جهت تأیید ای مساله که ای نشانی مال ایسانه اجرا کنین.',

# Change password dialog
'retypenew' => 'تایپ دوباره رمز:',

# Edit page toolbar
'bold_sample' => 'متن گپ نما',
'bold_tip' => 'متن گپ نما',
'italic_sample' => 'متن شکسته',
'italic_tip' => 'متن شکسته',
'link_sample' => 'عنوان لینک',
'link_tip' => 'لینک داخلی',
'extlink_sample' => 'http://www.example.com عنوان لینک',
'extlink_tip' => '(به خاطر بسپار http:// prefix)
لینک خارجی',
'headline_sample' => 'سرخط متن',
'headline_tip' => '2سرخط یکسان',
'nowiki_sample' => 'متن شکل نداده یافرمت نوابیده را ایچو بنین',
'nowiki_tip' => 'زه فرمت کردن یا شکل دادن ویکی چشم پوشی کن',
'image_tip' => 'فایل محاط وابید',
'media_tip' => 'لینک فایل',
'sig_tip' => 'امضای ایسا و برچسب زمان',
'hr_tip' => 'خط افقی (کم استفاده کنین)',

# Edit pages
'summary' => 'خلاصه:',
'subject' => 'موضوع/سرخط:',
'minoredit' => 'ای یه اصلاح ریزه-رز',
'watchthis' => 'پیگیری ای صفحه',
'savearticle' => 'صفحه ضبط بوه',
'preview' => 'پیش نمایش',
'showpreview' => 'پیش‌نمایش',
'showdiff' => 'نشودادن تغییرات',
'anoneditwarning' => "'''توجه:''' ایسا داخل سیستم نوابیدین.
آی پی آدرستو درگزارش اصلاح صفحه ضبط ابوه.",
'summary-preview' => 'پیش نمایش - خلاصه:',
'blockedtext' => ' "\'\'\'دسترسی نام کاربری یا نشانی اینترنتی ایسا بسته وابیده.\'\'\'
ای کار توسط $1 انجام شده‌است.
دلیلی که گده اینه: $2\'\'
* آغاز قطع دسترسی: $8
* زمان اتمام ای قطع دسترسی: $6
* کاربری که قطع دسترسی‌اش در نظر بیده: $7
ایساترین با $1 یا یکی از [[{{MediaWiki:Grouppage-sysop}}|مدیران]] تماس بگیرین و در ای باره صحبت کنین.
توجه کنین که ایسا نترین زه امکان «ارسال پست الکترونیکی به ای کاربر» استفاده کنین مگر این که نشانی پست الکترونیکی معتبری در [[Special:Preferences|اولویتهای کاربری]]خود ثبت کرده بوین.
نشانی IP ایسا $3 و شماره قطع دسترسی ایسا $5 است. لطفاً ای شماره‌ها را در همه کاوشهاتون ذکر کنین.
ایسا ترین با $1 یا یکی دیه زه [[{{MediaWiki:Grouppage-sysop}}|مدیران]] تماس بگیرین، تا در باره ای قطع دسترسی صحبت کنین.
دقت کنین که سی ارسال پست الکترونیکی در ویکی، وا پست الکترونیکی خود را زه طریق صفحه[[Special:Preferences|تنظیمات]] فعال کرده بوین، و نیز، وا امکان استفاده زه ای ویژگی سی ایساقطع نبوه.
نشانی اینترنتی الان ایسا $3 است و شماره قطع دسترسی $5 است.
لطفاً ای شماره را در هر درخواستی که در ای مورد مطرح اکنین ذکر کنین',
'newarticle' => '(تازه)',
'newarticletext' => 'ایسا لینکی را دنبال کردین و به صفحه‌ای رسیدین که هنی درست نوابیده.
سی ایجاد صفحه، داخل مستطیل زیر شروع به تایپ کنین (سی اطلاعات بیشتر به [[{{ns:project}}:راهنما|صفحه راهنما]] برین).
ایر اشتباهی ایچو اویدین دکمه «برگشت» مرورگرتو را بزنین.',
'noarticletext' => ' الان ای صفحه متنی نداره، ایسا ترین [[Special:Search/{{PAGENAME}}عنوان ای صفحه را در صفحه‌های دیگر جستجو کنین]] یا [{{fullurl:{{FULLPAGENAME}}|action=edit}} ای صفحه را اصلاح کنین].',
'previewnote' => "'''ای فقط یه پیش نمایشه;
تغییراتی که ایسا دادین هنی ضبط نوابیده!'''",
'editing' => 'درحال اصلاح $1',
'editingsection' => 'درحال اصلاح $1 (قسمت)',
'copyrightwarning' => "لطفاً دقت کنین که درنظر گریده ابوه که همه شراکتهای ایسا  {{SITENAME}} تحت «$2» منتشر ابون ).


(سی دیدن  جزئیات بیشتر به $1 برین

ایر نه خوین نوشته‌هاتو بی‌رحمانه اصلاح بوه و به دلخواه ارسال بوه، ایچو نفرستن.<br />
درضمن ایسادارین به ایما قول ادین که خودتو یونه نوشتین یا هونه زه یک منبع آزاد با مالکیت عمومی یا مثل هو ورداشتین. '''کارهای دارای کارهای دارای حق کپی رایت را بی‌اجازه نفرستین!'''',",
'templatesused' => 'قالبهای استفاده شده من ای صفحه:',
'templatesusedpreview' => 'قالبها  یا الگوهای استفاده وابیده در ای پیش نمایش:',
'template-protected' => '(تحت حمایت)',
'template-semiprotected' => '(نیمه حمایت وابیده)',
'nocreatetext' => '{{SITENAME}}قابلیت درست کردن صفحات تازه را محدود کرده‌. ترین برگردین و صفحه‌ موجود را اصلاح کنین یا اینکه  [[Special:UserLogin|به سیستم داخل بوین یا حساب کاربری درست کنین]].',
'recreate-moveddeleted-warn' => "'''هشدار: ایسا در حال درست کردن دوباره صفحه‌ای هدین که قبلاً حذف وابیده '''در نظر داشته بوین که ادامه اصلاح ای صفحه کار درستی هده یا نه. نمایه حذف مربوط به ای صفحه سی راحتی کار در ادامه اویده",

# History pages
'viewpagelogs' => 'نشودادن نمایه ها سی ای صفحه',
'currentrev' => 'نسخه جاری',
'revisionasof' => 'اصلاح $1',
'revision-info' => 'یه نسخه اصلاح شده درتاریخ  $1 بوسیله $2',
'previousrevision' => '← اصلاح قبلی',
'nextrevision' => 'نسخه بعدی →',
'currentrevisionlink' => 'نسخه جاری',
'cur' => 'فعلی',
'last' => 'قبلی',
'page_first' => 'اولین',
'page_last' => 'آخری',
'histlegend' => "انتخاب متفاوت: علامت بنین رو رادیو جعبه ها زه آن نسخه ها سی مقایسه وامتیاز دادن ویا داخل تکمه های زیر سی مسابقه بوین  .<br />
'شرح: (فعلی) = تفاوت با نسخه جاری
(قبلی) = تفاوت با نسخه قبلی، جز = ویرایش جزئی',",
'histfirst' => 'کهنه ترین',
'histlast' => 'تازه ترین',

# Revision feed
'history-feed-item-nocomment' => '$1 در $2',

# Diffs
'history-title' => 'گزارش تاریخی نسخه زه "$1"',
'lineno' => 'سطر $1:',
'compareselectedversions' => 'مقایسه نسخه‌های انتخاب‌ وابیده',
'editundo' => 'لغو اصلاح آخر',
'diff-multi' => '({{PLURAL:$1|یه اصلاح میانی|$1 اصلاحات میانی}} نشو داده نوابیده.)',

# Search results
'prevn' => 'قبلی {{PLURAL:$1|$1}}',
'nextn' => 'بعدی {{PLURAL:$1|$1}}',
'viewprevnext' => 'مشاهده ($1 {{int:pipe-separator}} $2) ($3)',
'searchhelp-url' => 'Help:محتوا',
'powersearch' => 'جستجوی کاملتر',

# Preferences page
'preferences' => 'اولویتها',
'mypreferences' => 'اولویتهای مو',
'yourrealname' => 'نام واقعی:',
'prefs-help-realname' => 'ذکر نام واقعی اختیاریه ایر تصمیم به گدن بگیرین هنگام ارجاع به آثارتو و انتساب هونو به ایسا زه نام واقعیتو استفاده ابوه',

'grouppage-sysop' => '{{ns:project}}:مدیران',

# User rights log
'rightslog' => 'نمایه حقوق کاربر',

# Recent changes
'nchanges' => '$1 {{PLURAL:$1|تغییر|تغییرات}}',
'recentchanges' => 'تغییرات اخیر',
'recentchanges-feed-description' => 'ردیابی آخرین تغییرات  ویکی در ای خورد',
'rcnote' => "در زیر {{PLURAL:$1|'''۱''' تغییر|آخرین '''$1''' تغییر}} در آخرین {{PLURAL:$2|روز|'''$2''' روز}} را، تا $5، $4 ابینین.",
'rcnotefrom' => 'در زیر تغییرات زه تاریخ <b>$2</b> آمده‌اند (تا <b>$1</b> مورد نشو داده ابوه).',
'rclistfrom' => 'نشودادن تغییرات تازه با شروع زه $1',
'rcshowhideminor' => 'اصلاحات کوچیک $1',
'rcshowhidebots' => '$1 ربات‌ها یا بوتها',
'rcshowhideliu' => '$1 کاربران داخل وابیده',
'rcshowhideanons' => '$1 کاربران داخل نوابیده',
'rcshowhidepatr' => '$1 اصلاحات پاسداری شده',
'rcshowhidemine' => '$1 اصلاحات مو',
'rclinks' => 'نشودادن آخرین $1 تغییر در $2 روز اخیر؛ $3',
'diff' => 'تفاوت',
'hist' => 'گزارش',
'hide' => 'قایم شدن',
'show' => 'نشودادن',
'minoreditletter' => 'رز',
'newpageletter' => 'تا',
'boteditletter' => 'ر',

# Recent changes linked
'recentchangeslinked' => 'تغییرات مرتبط',
'recentchangeslinked-feed' => 'تغییرات مرتبط',
'recentchangeslinked-toolbox' => 'تغییرات مرتبط',
'recentchangeslinked-title' => 'تغییرهای مرتبط با $1',
'recentchangeslinked-noresult' => 'در دوره زمانی داده‌شده تغییری در صفحه‌های لینک داده رخ نداده‌',
'recentchangeslinked-summary' => " ای صفحه خاص تغییرات اخیر در صفحه‌های لینک داده شده به این صفحه را نشو اده.
صفحه‌هایی که در لیست پی‌گیریهای ایسا بون به شکل '''سیاه''' نشو داده ابون.",

# Upload
'upload' => 'آپلود فایل',
'uploadbtn' => 'آپلود فایل',
'uploadlogpage' => 'نمایه آپلود',
'uploadedimage' => 'آپلود وابید "[[$1]]"',

# Special:ListFiles
'listfiles' => 'لیست فایل',

# File description page
'file-anchor-link' => 'فایل',
'filehist' => 'گزارش تاریخی فایل',
'filehist-help' => 'رو تاریخ‌ها کلیک کنید تا نسخه مرتبط را ببینین.',
'filehist-current' => 'جاری',
'filehist-datetime' => 'تاریخ/زمان',
'filehist-user' => 'کاربر',
'filehist-dimensions' => 'ابعاد',
'filehist-filesize' => 'اندازه فایل',
'filehist-comment' => 'توضیح',
'imagelinks' => 'لینکها',
'linkstoimage' => 'ذیل الذکر {{PLURAL:$1|لینکهای صفحه|$1 لینک صفحات}} به ای فایل:',
'nolinkstoimage' => 'هیچ صفحه ای نه که لینک وابیده بوه به ای فایل',
'sharedupload' => 'ای فایل یک آپلود اشتراکی هده و ممکنه زه طریق  پروژه‌های دیگه  هم قابل دسترسی بوه',
'uploadnewversion-linktext' => 'آپلود کردن یه نسخه تازه زه ای فایل',

# MIME search
'mimesearch' => 'MIME جستجو رو پایه',

# List redirects
'listredirects' => 'لیست تغییر مسیرها',

# Unused templates
'unusedtemplates' => 'قالبها یا الگوهای استفاده نوابیده',

# Random page
'randompage' => 'صفحه اتفاقی',

# Random redirect
'randomredirect' => 'تغییر مسیر اتفاقی',

# Statistics
'statistics' => 'آمار',

'disambiguations' => 'صفحات رفع ابهام',

'doubleredirects' => 'تغییر مسیر دوبله',

'brokenredirects' => 'تغییرمسیرهای اشکسته وخراو',

'withoutinterwiki' => 'صفحات بدون لینک های زبانی میان ویکی',

'fewestrevisions' => 'صفحات با کمترین تعداداصلاحات وتجدیدنظرها',

# Miscellaneous special pages
'nbytes' => '$1 {{PLURAL:$1|بایت|بایت}}',
'nlinks' => '$1 {{PLURAL:$1|لینک|لینکها}}',
'nmembers' => '$1 {{PLURAL:$1|عضو|اعضا}}',
'lonelypages' => 'صفحات یتیم وابیده',
'uncategorizedpages' => 'صفحات دسته بندی نوابیده',
'uncategorizedcategories' => 'دسته های دسته بندی نوابیده',
'uncategorizedimages' => 'فایلهای تصویری دسته بندی نوابیده',
'uncategorizedtemplates' => 'قالبها یا الگوهای دسته بندی نوابیده',
'unusedcategories' => 'دسته های استفاده نوابیده',
'unusedimages' => 'فایلهای استفاده نوابیده',
'wantedcategories' => 'دسته های  درخواستی',
'wantedpages' => 'صفحات درخواستی',
'mostlinked' => 'صفحاتی که بیشتر زه همه به هونو لینک داده وابیده',
'mostlinkedcategories' => 'دسته هایی که بیشتر زه همه به هونو لینک داده وابیده',
'mostlinkedtemplates' => 'قالبها یا الگوهایی که بیشتر زه همه به هونو لینک داده وابیده',
'mostcategories' => 'صفحات با بیشترین تعداد دسته بندی',
'mostimages' => 'تصاویری که بیشتر زه همه به هونو لینک داده وابیده',
'mostrevisions' => 'صفحات با تعداد اصلاحات زیاد',
'prefixindex' => 'نمایه پیشوندی',
'shortpages' => 'صفحات کوتاه',
'longpages' => 'صفحات بلند',
'deadendpages' => 'صفحات بن بست ولاینحل',
'protectedpages' => 'صفحات حفاظت وحمایت وابیده',
'listusers' => 'لیست کاربر',
'newpages' => 'صفحات تازه',
'ancientpages' => 'کهنه ترین صفحات',
'move' => 'جابجا کردن',
'movethispage' => 'جابجایی ای صفحه',

# Book sources
'booksources' => 'منابع کتاب',

# Special:Log
'specialloguserlabel' => 'کاربر:',
'speciallogtitlelabel' => 'عنوان:',
'log' => 'نمایه ها',
'all-logs-page' => 'همه نمایه ها',

# Special:AllPages
'allpages' => 'همه صفحات',
'alphaindexline' => '$1 به
$2',
'nextpage' => 'صفحه بعدی ($1)',
'prevpage' => 'صفحه قبلی($1)',
'allpagesfrom' => 'نمایش دادن صفحات با شروع زه:',
'allarticles' => 'همه صفحات',
'allpagessubmit' => 'برو',
'allpagesprefix' => 'نشو دادن صفحات همراه با پیشوند:',

# Special:Categories
'categories' => 'دسته ها',

# Email user
'emailuser' => 'امیل ای کاربر',

# Watchlist
'watchlist' => 'لیست پیگیریهای مو',
'mywatchlist' => 'لیست پیگیریهای مو',
'addedwatchtext' => "صفحه «<nowiki>$1</nowiki>» به [[Special:Watchlist|لیست پی‌گیری‌های ]] ایسا
اضاف وابید.
تغییرات این صفحه و صفحه صحبت مر بوطه اش در آینده ایچو لیست ابوه. به‌علاوه، ای صفحه، سی واضح‌تر دیده وابیدن در [[Special:RecentChanges|فهرست تغییرات اخیر]] به شکل <b>سیاه</b> ایا.

ایر بعدا خواستین ای  صفحه زه لیست پی‌گیریهاتو ورداشته بوه، رو «'''عدم پی‌گیری'''» در بالای صفحه کلیک کنین.",
'removedwatchtext' => 'آن صفحه"[[:$1]]" جابجا وابیده زه[[Special:لیست پیگیری|لیست پیگیری ایسا]].',
'watch' => 'پی‌گیری',
'watchthispage' => 'پیگیری ای صفحه',
'unwatch' => 'عدم پیگیری',
'watchlist-details' => '{{PLURAL:$1|$1 صفحه|$1 صفحات}} درلیست پیگیری ایسا, صفحات صحبت حساب نیبوه.',
'wlshowlast' => 'نمایش آخرین $1 ساعت $2 روز $3',

# Displayed when you click the "watch" button and it is in the process of watching
'watching' => 'درحال پیگیری...',
'unwatching' => 'درحالت عدم پیگیری...',

# Delete
'deletepage' => 'حذف صفحه',
'historywarning' => 'توجه: آن صفحه ای که ایسا اخوین حذف کنین گزارش تاریخی داره:',
'confirmdeletetext' => 'ایسا اخوین یه صفحه بلند با همه گزارش تاریخی هونه حذف کنین.
لطفا کانفیرم یا تائید کنین که تمایل وقصد ای کار را دارین, وایسا دوین یا می دانید نتایج وآثار ای کار را, و ایسا انجام ادین ای کار را مطابق با [[{{MediaWiki:Policy-url}}|سیاست‌ها]].',
'actioncomplete' => 'عمل  مربوطه راکامل کن',
'deletedtext' => '"$1" حذف وابیده.
بوین $2 سی ثبت حذف آخر.',
'dellogpage' => 'نمایه _ حذف',
'deletecomment' => 'دلیل:',
'deleteotherreason' => 'دیه/دلیل اضافی:',
'deletereasonotherlist' => 'دلیل دیه',

# Rollback
'rollbacklink' => 'عقب گرد',

# Protect
'protectlogpage' => 'نمایه حفاظت وحمایت',
'prot_1movedto2' => '[[$1]] جابجا وابید به[[$2]]',
'protectcomment' => 'دلیل:',
'protectexpiry' => 'سپری وابیده ها:',
'protect_expiry_invalid' => 'با سپری وابیدن وقت غیر معتبره.',
'protect_expiry_old' => 'سپری وابیدن وقت مربوط به گذشته.',
'protect-text' => "ایسا ممکنه بوینین وتغییر بدین سطح حمایت زه ای صفحه'''$1'''.",
'protect-locked-access' => "حساب کاربری ایسا اجازه تغییر سطح حمایت ای صفحه را نداره.
ای چونه تنظیمات جاری سی آن صفحه '''$1''':",
'protect-cascadeon' => 'ای صفحه  در حال حاضر حفاظت وحمایت وابیده چون که در {{PLURAL:$1|صفحه|صفحات}}
زیر که گزینه حفاظت وحمایت موجی {{PLURAL:$1|آن|آن‌ها}} فعال هده ،
ایسا ترین سطح حفاظت ای صفحه را تغییر بدین اما ای کارنتره تاثیری رو
حفاظت وحمایت موجی صفحه داشته بوه.',
'protect-default' => '(پیش فرض)',
'protect-fallback' => 'درخواست"$1" اجازه',
'protect-level-autoconfirmed' => 'بستن کاربران ثبت نام نوابیده',
'protect-level-sysop' => 'Sysops فقط',
'protect-summary-cascade' => 'موجی کردن',
'protect-expiring' => 'سپری وابیده $1 (UTC)',
'protect-cascade' => 'حمایت صفحات دربرگیرنده در ای صفحه (cascading protection)',
'protect-cantedit' => 'ایسا نترین تغییر بدین سطوح حمایتی ای صفحه را, زیرا ایسا اجازه اصلاح آن را ندارین.',
'protect-expiry-options' => '۱ ساعت:1 hour,۱ روز:1 day,۱ هفته:1 week,۲ هفته:2 weeks,۱ ماه:1 month,۳ ماه:3 months,۶ ماه:6 months,۱ سال:1 year,بی‌نهایت:infinite',
'restriction-type' => 'اجازه:',
'restriction-level' => 'سطح محدودیت:',

# Undelete
'undeletebtn' => 'بازیافت',

# Namespace form on various pages
'namespace' => 'فضای نام:',
'invert' => 'انتخاب برعکس بوه',
'blanknamespace' => '(اصلی)',

# Contributions
'contributions' => 'شراکتهای کاربر',
'mycontris' => 'شراکتهای مو',
'contribsub2' => 'سی $1 ($2)',
'uctop' => '(بالا)',
'month' => 'در این ماه (و قبل زه آن):',
'year' => 'در ای سال (وقبل زه آن):',

'sp-contributions-newbies-sub' => 'سی حسابهای کاربری تازه',
'sp-contributions-blocklog' => 'نمایه بسته وابیده ها',
'sp-contributions-talk' => 'صحبت',

# What links here
'whatlinkshere' => 'لینک های ای صفحه',
'whatlinkshere-title' => 'صفحات آن لینک به "$1"',
'linkshere' => "لینک صفحات ذیل الذکر به '''[[:$1]]''':",
'nolinkshere' => "هیچ صفحه ای پیوند نداردبه '''[[:$1]]'''.",
'isredirect' => 'صفحه تغییر مسیر',
'istemplate' => 'استفاده‌ وابیده داخل صفحه',
'whatlinkshere-prev' => '{{PLURAL:$1|قبلی |مورد قبلی$1}}',
'whatlinkshere-next' => '{{PLURAL:$1|بعدی |مورد بعدی $1}}',
'whatlinkshere-links' => '← لینکها',

# Block/unblock
'blockip' => 'بستن کاربر',
'ipboptions' => '۲ ساعت:2 hours,۱ روز:1 day,۳ روز:3 days,۱ هفته:1 week,۲ هفته:2 weeks,۱ ماه:1 month,۳ ماه:3 months,۶ ماه:6 months,۱ سال:1 year,بی‌نهایت:infinite',
'ipblocklist' => 'آدرسهای  آی پی وکاربران بسته وابیدند',
'blocklink' => 'بسته بوه !',
'unblocklink' => 'باز بوه',
'contribslink' => 'شراکت',
'blocklogpage' => 'نمایه _ بسته‌وابیده‌ها',
'blocklogentry' => 'بسته وابید [[$1]] با سپری وابیدن وقت زه $2 $3',

# Move page
'movepagetext' => "با استفاده زه فرم زیر نام صفحه تغییر اکنه و همه گزارش تاریخی هو به نام تازه جابجا ابوه.
عنوان کهنه تبدیل به یک صفحه تغییر مسیر به عنوان جدید ابوه.
ایسا ترین بطور اتوماتیک تغییر مسیر های مربوط به عنوان اصلی رو به روز رسانی کنین. ایر ایسا مطمئن نهدین با دیدن یونو مطمئن بوین:
[[Special:تغییر مسیر دوبل|دوبل ]] یا[[Special:تغییرمسیر خروا یا اشکسته|تغییرمسیرهای خراو یا اشکسته]].

لینکهایی که به عنوان صفحه قدیمی هدن تغییر نه کنن حتماً تغییر مسیرهای دوبل یا اشکسته و خراو را بررسی کنین.
'''ایسا''' مسئول اطمینان زه یو هدین که لینکها هنی به همان‌جایی که قرار هده برن.

توجه کنین که ایر زه قبل صفحه‌ای در عنوان تازه وجود داشته بوه صفحه منتقل '''نه بوه'''،
میر یو که آن صفحه خالی یا تغییر مسیر بوه و گزارش تاریخی اصلاح نداشته بوه.
 یعنی ایر اشتباه کردین ترین صفحه را به همان جایی که زه هو جابجا وابیدین برگردانین، و  نترین رو صفحات موجود بنویسین

'''هشدار!'''
جابجایی صفحات به نام تازه ممکنه  تغییر کلی و غیرمنتظره‌ای سی
 صفحات دوست داشتنی داشته بوه ؛
لطفاً مطمئن بوین که قبل زه جابجا کردن صفحه، عواقب ای کار را درک اکنین.",
'movepagetalktext' => "صفحه صحبت مربوط، ایر وجود داشته بوه، بطور اتوماتیک همراه با صفحه اصلی
 جابجا ابوه '''میر یو که''' :
* در حال جابجایی صفحه زه ای فضای نام به فضای نام دیگری بوین،
* یه صفحه صحبت غیرخالی تحت ای نام تازه وجود داشته بوه، یا
* کادر زیر را تیک نزده بوین.

در ای موارد، وا صفحه را بطور دستی جابجا کرده و یا محتویات دو صفحه را با اصلاح ادغام کنین.",
'movearticle' => 'جابجایی صفحه:',
'newtitle' => 'به عنوان تازه:',
'move-watch' => 'پیگیری ای صفحه',
'movepagebtn' => 'جابجایی صفحه',
'pagemovedsub' => 'جابجایی با بخت وتوفیق انجام وابید',
'movepage-moved' => '\'\'\'"$1" جابجا وابیده به "$2"\'\'\'',
'articleexists' => 'یه صفحه زه ای  نوم تقریبا موجوده, یا نومی که ایسا انتخاب کردین غیر  معتبره
لطفا نوم دیه انتخاب کنین.',
'talkexists' => "'''آن صفحه خوس با بخت وتوفیق جابجا وابید, ولی صفحه صحبت نتره جابجا بوه چونکه یکی تقریبا موجوده درعنوان تازه
لطفا به صورت دستی آنها را ترکیب کنین.'''",
'movedto' => 'جابجا وابید به',
'movetalk' => 'جابجایی صفحه صحبت مربوطه',
'movelogpage' => 'نمایه جابجایی',
'movereason' => 'دلیل:',
'revertmove' => 'واگردانی',

# Export
'export' => 'صفحات صادره',

# Namespace 8 related
'allmessages' => 'پیامهای سیستم',

# Thumbnails
'thumbnail-more' => 'گپ کردن',
'thumbnail_error' => 'خطا سی درست کردن ناخن دانه: $1',

# Import log
'importlogpage' => 'داخل نمایه کردن',

# Tooltip help for the actions
'tooltip-pt-userpage' => 'صفحه کاربری مو',
'tooltip-pt-mytalk' => 'صفحه صحبت مو',
'tooltip-pt-preferences' => 'اولویت های مو',
'tooltip-pt-watchlist' => 'لیست صفحه‌هایی که ایسا تغییرات هونو  دنبال اکنین',
'tooltip-pt-mycontris' => 'لیست شراکتهای مو',
'tooltip-pt-login' => 'توصیه ابوه که به سیستم داخل بوین اما اجباری نه.',
'tooltip-pt-logout' => 'رهدن زه سیستم',
'tooltip-ca-talk' => 'صحبت درباره صفحه محتوا',
'tooltip-ca-edit' => 'ایسا ترین ای  صفحه را اصلاح کنین. لطفاً قبل  ذخیره کردن زه دکمه پیش‌ نمایش استفاده کنین',
'tooltip-ca-addsection' => 'اضاف کردن یه توضیح به ای مبحث',
'tooltip-ca-viewsource' => 'ای صفحه  تحت حمایته ایساترین منبعسه بوینین',
'tooltip-ca-protect' => 'حفاظت وحمایت زه ای صفحه',
'tooltip-ca-delete' => 'حذف ای صفحه',
'tooltip-ca-move' => 'جابجاکردن ای صفحه',
'tooltip-ca-watch' => 'اضاف کردن ای صفحه به لیست پیگیریهاتو',
'tooltip-ca-unwatch' => 'حذف ای صفحه زه لیست پی‌گیری‌های ایسا',
'tooltip-search' => 'جستن {{SITENAME}}',
'tooltip-n-mainpage' => 'دیدن صفحه اصلی',
'tooltip-n-portal' => 'درباره ای پروژه چه ترین  کنین و  کیه  ترین آن جیزها رو پیدا کنین',
'tooltip-n-currentevents' => 'پیداکردن اطلاعات زمینه یاسابقه اطلاعات در اتفاقات جاری',
'tooltip-n-recentchanges' => 'فهرست  تغییرات آخری درویکی',
'tooltip-n-randompage' => 'لود کردن یه صفحه بطور اتفاقی',
'tooltip-n-help' => 'محلی برای کشف کردن',
'tooltip-t-whatlinkshere' => 'فهرست همه صفحات ویکی که ایچو لینک دارن',
'tooltip-t-recentchangeslinked' => 'تغییرات آخری  درصفحاتی که لینک شده اند به ای صفحه',
'tooltip-feed-rss' => 'تغذیه آراس اس برای ای صفحه',
'tooltip-feed-atom' => 'تغذیه کوچیک ترین جزء  ای صفحه',
'tooltip-t-contributions' => 'دیدن فهرست مشارکت کننده ها ومقاله دهنده های ای صفحه',
'tooltip-t-emailuser' => 'ارسال یه امیل به ای کاربر',
'tooltip-t-upload' => 'آپلودکردن فایلها',
'tooltip-t-specialpages' => 'فهرست همه صفحات مخصوص',
'tooltip-t-print' => 'نسخه فابل پرینت ای صفحه',
'tooltip-t-permalink' => 'لینک دایمی به ای نسخه از صفحه',
'tooltip-ca-nstab-main' => 'دیدن آن صفحه محتوا',
'tooltip-ca-nstab-user' => 'دیدن صفحه کاربر',
'tooltip-ca-nstab-media' => 'دیدن صفحه مدیا',
'tooltip-ca-nstab-special' => 'ای صفحه مخصوصه وایسا نترین خود ای صفحه رااصلاح کنین',
'tooltip-ca-nstab-project' => 'دیدن صفحه پروژه',
'tooltip-ca-nstab-image' => 'دیدن صفحه فایل',
'tooltip-ca-nstab-mediawiki' => 'دیدن پیام سیستم',
'tooltip-ca-nstab-template' => 'دیدن قالب قابل تغییر',
'tooltip-ca-nstab-help' => 'دیدن صفحه کمک',
'tooltip-ca-nstab-category' => 'دیدن صفحه طبقه بندی',
'tooltip-minoredit' => 'علامت نهادن به این به عنوان اصلاح حداقل یاکم',
'tooltip-save' => 'ضبط کردن تغییرات',
'tooltip-preview' => ' زه قبل دیدن تغییرات قبل از ضبط کردن سی مطمئن وابیدن لطفا استفاده کنید قبل از ضبط کردن',
'tooltip-diff' => 'دیدن تغییراتی که ایسا من ای متن انجام دادین',
'tooltip-compareselectedversions' => 'دیدن تفاوتهای بین دونسخه انتخاب وابیده زه ای صفحه',
'tooltip-watch' => 'اضاف کردن ای صفحه به فهرست مشاهداتتان',
'tooltip-recreate' => 'دوباره درست کردن صفحه ای که زه رو کینه وغرض پاک وابیده',
'tooltip-upload' => 'شروع آپلود',
'tooltip-rollback' => '"اعاده" برگرداندن به وضع اولیه سی ای صفحه که بخاطر مشارکت  آخر اصلاح وابیده بایک کلیک',

# Browsing diffs
'previousdiff' => '← اصلاح قدیمی',
'nextdiff' => 'تفاوت بعدی→',

# Media information
'file-info-size' => '$1 × $2 پیکسل, اندازه فایل: $3, MIME نوع: $4',
'file-nohires' => 'قابلیت تفکیک بالاتری در دسترس نه.',
'svg-long-desc' => 'SVG فایل, تقریبا$1 × $2 پیکسل, اندازه فایل: $3',
'show-big-image' => 'تصویر با قابلیت تفکیک کامل',

# Special:NewFiles
'newimages' => 'گالری فایلهای تازه',

# Bad image list
'bad_image_list' => 'اطلاعات را وا به ای شکل وارد کنین:

فقط سطرهایی که با * آغاز ابون در نظر گریده ابون. اولین لینک در هر سطر، باید لینکی به یک تصویر بد باشد.
لینکهای بعدی در همان سطر، به عنوان موارد استثنا در نظر گریده ابون',

# Metadata
'metadata' => 'فراداده',
'metadata-help' => ' ای فایل دارای اطلاعات اضافه‌ای است که احتمالاً با دوربین دیجیتالی‌ یا پویشگری که سی ایجاد یا دیجیتالی‌کردن آن به کار رهده اضاف وابیده . ایر فایل زه وضعیت اولیه اس تغییر داده وابیده بوه ممکنه همه توضیحات موجود اطلاعات عکس را منعکس نکنه',
'metadata-expand' => 'نشودادن جزئیات تفصیلی',
'metadata-collapse' => 'قایم کردن جزئیات تفصیلی',
'metadata-fields' => 'فراداده EXIF نشو داده وابیده در این پیام وقتی جدول فراداده‌های تصویر جمع وابیده بوه هم نمایش داده ابوه.
بقیه موارد فقط وقتی نشوداده ابوه که جدول یادشده واز بوه.
* make
* model
* datetimeoriginal
* exposuretime
* fnumber
* isospeedratings
* focallength
* artist
* copyright
* imagedescription
* gpslatitude
* gpslongitude
* gpsaltitude',

# External editor support
'edit-externally' => 'اصلاح ای صفحه با استفاده زه یه ویرایشگر خارجی',
'edit-externally-help' => ' سی اطلاعات بیشتر [//www.mediawiki.org/wiki/Manual:External_editors راهنمایی‌های تنظیمات] اصلاح کننده خارجی را بوینین.',

# 'all' in various places, this might be different for inflected languages
'watchlistall2' => 'همه',
'namespacesall' => 'همه',
'monthsall' => 'همه ماهها',

# Watchlist editing tools
'watchlisttools-view' => 'نشودادن تغییرات مربوطه',
'watchlisttools-edit' => 'نشودادن واصلاح کردن لیست پیگیریها',
'watchlisttools-raw' => 'اصلاح لیست خام پی‌گیری‌ها',

# Special:Version
'version' => 'ترجمه یا تفسیر',

# Special:SpecialPages
'specialpages' => 'صفحات ویژه',

);
